[![Build Status](https://travis-ci.org/artificilabs/trellio.svg?branch=master)](https://travis-ci.org/artificilabs/trellio)

# trellio

Python 3 asyncio based micro-framework for micro-service architecture
